/*
 * FILE:    connectable.h
 * PACKAGE: PNML view
 * LICENCE: See LICENCE file
 * AUTHOR:  Freek van Walderveen
 *
 */

#ifndef CONNECTABLE_H
#define CONNECTABLE_H

#include "drawable.h"

#include <QString>
#include <QPoint>
#include <QSize>
#include <QRect>
#include <QVector>

class Arc;

class Connectable : public Drawable {
public:
  enum ConType { Transition, Place };

  Connectable();
  virtual ~Connectable();
  
  virtual bool containsPos(QPoint pos) const;
  
  // Function to find a point where a line from `source' could be connected to.
  virtual const QPointF getConnectionPoint(QPointF source) const = 0;

  inline ConType getConType() const;
  
  virtual const QRect getBoundingRect() const = 0;
  
  inline const QPoint getPosition() const;
  inline void setPosition (QPoint value);
  inline const QSize getSize() const;
  inline void setSize(QSize value);
  inline const QString getDescription() const;
  inline void setDescription(QString value);
  inline void addArc(Arc *arc);
  inline const QVector<Arc *> getArcs() const;
  const QVector<Connectable *> getPreSet() const;
  const QVector<Connectable *> getPostSet() const;
  const QVector<Connectable *> getAssocStores() const;
  const QVector<Connectable *> getInhibits() const;
  const QVector<Connectable *> getResets() const;
  
  virtual const QString getToolTip() const;
  
protected:
  QString markup(QString str, QString header = QString(), bool monoSpaced = false) const;
  
  QPoint position;
  QSize size;
  QString description;
  ConType conType;
  QVector<Arc *> arcs;
    
private:
};

inline Connectable::ConType Connectable::getConType() const {
  return conType;
}

inline const QPoint Connectable::getPosition() const {
  return position;
}

inline void Connectable::setPosition(QPoint value) {
  position = value;
}

inline const QSize Connectable::getSize() const {
  return size;
}

inline void Connectable::setSize(QSize value) {
  size = value;
}

inline const QString Connectable::getDescription() const {
  return description;
}

inline void Connectable::setDescription(QString value) {
  description = value;
}

inline void Connectable::addArc(Arc *arc) {
  arcs << arc;
}

inline const QVector<Arc *> Connectable::getArcs() const {
  return arcs;
}

#endif //CONNECTABLE_H
