/*
 * FILE:    drawable.h
 * PACKAGE: PNML view
 * LICENCE: See LICENCE file
 * AUTHOR:  Freek van Walderveen
 *
 */

#ifndef DRAWABLE_H
#define DRAWABLE_H

#include <QString>
#include <QPoint>

class LabelPlacer;
class DrawProps;
class QPainter;

class Drawable {
public:
  Drawable() { }
  virtual ~Drawable() { }
  virtual void draw (QPainter *p, DrawProps *drawProps) = 0; // Pre: p.isActive() && drawProps
  virtual void updateLabels(LabelPlacer *labelPlacer, DrawProps *drawProps); // Pre: labelPlacer && drawProps
  virtual bool containsPos(QPoint pos) const = 0;
  
  inline const QString getId() const;
  inline void setId(QString value);
  inline const QString getName() const;
  inline void setName(QString value);
  inline const QString getNameOrId() const;
  
  virtual const QString getToolTip() const = 0;
  
protected:
  QString id;
  QString name;

private:
};

inline const QString Drawable::getId() const {
  return id;
}
inline void Drawable::setId(QString value) {
  id = value;
}
inline const QString Drawable::getName() const {
  return name;
}
inline void Drawable::setName(QString value) {
  name = value;
}
inline const QString Drawable::getNameOrId() const {
  return (name.isEmpty())?id:name;
}

#endif //DRAWABLE_H
