/*
 * FILE:    drawprops.h
 * PACKAGE: PNML view
 * LICENCE: See LICENCE file
 * AUTHOR:  Freek van Walderveen
 *
 */

#ifndef DRAWPROPS_H
#define DRAWPROPS_H

#include <QPen>
#include <QBrush>
#include <QFont>
#include <QPainterPath>
#include <QString>
#include <QMap>
#include <QRegion>
#include <QStringList>

// Defines that belong in DrawProps
#define SHADOW_SIZE     3     // offset of shadows
#define INLINE_ROUNDING 1500  // rouding of inline-page-rectangle; higher=more rounded
#define INHIBITOR_SIZE  4     // radius of inhibitor-dot
#define LABEL_DISTANCE  5     // clear distance from object to label


class DrawProps {
public:
  DrawProps();
  virtual ~DrawProps();
  
  QPen pen(QString name) const;
  void setPen(QString name, QPen value);
  QBrush brush(QString name) const;
  void setBrush(QString name, QBrush value);
  QFont font(QString name) const;
  void setFont(QString name, QFont value);
  bool option(QString name) const;
  void setOption(QString name, bool value);
  QString string(QString name) const;
  void setString(QString name, QString value);
  QPainterPath shape(QString name) const;
  double zoom() const;
  void setZoom(double value);
  
  QStringList penNames() const;
  QStringList brushNames() const;
  QStringList fontNames() const;
  QStringList optionNames() const;
  
  // Reset to factory defaults
  void resetAll();
  void resetPens();
  void resetBrushes();
  void resetFonts();
  void resetOptions();
  void resetStrings();
  void resetShapes();
  
  void loadSettings();
  void saveSettings() const;
  
  // Set draw properties such that printing (and pdf export) won't fail
  void setPrintSafe();
  
  // Currently only used to workaround the windows clipping problem
  QRegion updateRegion;
  
protected:
  double m_zoom;
  QMap<QString, QPen> pens;
  QMap<QString, QBrush> brushes;
  QMap<QString, QFont> fonts;
  QMap<QString, bool> options;
  QMap<QString, QString> strings;
  QMap<QString, QPainterPath> shapes;
  
private:
};


#endif //DRAWPROPS_H
