/*
 * FILE:    drawwidget.h
 * PACKAGE: PNML view
 * LICENCE: See LICENCE file
 * AUTHOR:  Freek van Walderveen
 *
 */

#ifndef DRAWWIDGET_H
#define DRAWWIDGET_H

#include <QWidget>
#include <QTimer>

class Net;
class DrawProps;

class DrawWidget : public QWidget {
  Q_OBJECT

public:
  DrawWidget(DrawProps *dp, QWidget * parent = 0, Qt::WFlags flags = 0); // Pre: dp
  virtual ~DrawWidget();
  void setNet(Net *value);
  Net *getNet() const;
  void sizeChanged();
  inline void setToolTips(bool value);

protected:
  virtual void paintEvent(QPaintEvent *e);
  virtual QSize sizeHint() const;
  void mouseReleaseEvent(QMouseEvent *e);
  void mouseMoveEvent(QMouseEvent *e);

private slots:
  void showToolTip();
    
private:
  Net *net; // Note: may be NULL
  DrawProps *drawProps; // { inv.: pointer is non-NULL and valid }
  bool showToolTips;
  QTimer toolTipTimer;
  QPoint lastMousePos;

};

inline void DrawWidget::setToolTips(bool value) {
  showToolTips = value;
}

#endif //~DRAWWIDGET_H
