/*
 * FILE:    net.h
 * PACKAGE: PNML view
 * LICENCE: See LICENCE file
 * AUTHOR:  Freek van Walderveen
 *
 */

#ifndef NET_H
#define NET_H

#include "labelplacer.h"

#include <QString>
#include <QVector>
#include <QMap>

class QPaintDevice;
class QTreeWidgetItem;
class QSize;
class Arc;
class Place;
class Connectable;
class Comment;
class Page;
class DrawProps;

class Net {
public:
  enum DirtyFlag {
    DirtyZoom       = 0x0001,
    DirtyDrawProp   = 0x0002,
    DirtyDrawables  = 0x0004,
    DirtyLabels     = 0x0008,
  
    AllDirty        = 0xffff
  };
  Q_DECLARE_FLAGS(DirtyFlags, DirtyFlag)
  
  Net();
  virtual ~Net();

  void draw (QPaintDevice *pd, DrawProps *drawProps, bool bypassCache = false); // Pre: pd, drawProps
  QString key() const;
  
  void addConnectable(Connectable *con);
  void addArc(Arc *arc);
  void addComment(Comment *comment);
  void addPage(Page *page);
  
  bool isEmpty();
  
  Connectable *findConnectableById(QString id) const;
  void updateHierarchy(QTreeWidgetItem *tree) const; // Pre: root
  QSize getSize(DrawProps *drawProps);
  QVector<Page *> getPages() const;
  QVector<Connectable *> getConnectables() const;
  QVector<Arc *> getArcs() const;
  
  void setDirty(DirtyFlags df, bool recursive = true);
  void solveDirty(DrawProps *drawProps, QPainter *painter = NULL); // Pre: drawProps && (painter ? painter.isActive() : true)
  QPoint demapPos(QPoint pos, DrawProps *drawProps);
  
  inline void setParent(Net *net);
  inline Net *getParent() const;
  
  QMap<QString, QString> roles; //TODO: make protected & install some accessors
  
protected:
  // { inv: all elements of connectables, arcs, comments and pages are non-NULL, valid pointers }
  QVector<Connectable *> connectables;
  QVector<Arc *> arcs;
  QVector<Comment *> comments;
  QVector<Page *> pages; // Note: pages is a subset of connectables
  
  
  QRect boundingBox;
  
  Net *parent; // may be NULL
  
  LabelPlacer labelPlacer;
  DirtyFlags dirtyFlags;

private:

};

Q_DECLARE_OPERATORS_FOR_FLAGS(Net::DirtyFlags)

inline void Net::setParent(Net *net) {
  parent = net;
}

inline Net *Net::getParent() const {
  return parent;
}

#endif //NET_H
