/*
 * FILE:    place.h
 * PACKAGE: PNML view
 * LICENCE: See LICENCE file
 * AUTHOR:  Freek van Walderveen
 *
 */

#ifndef PLACE_H
#define PLACE_H

#include "connectable.h"

class QPainter;


class Place : public Connectable {
public:
  enum Type { Channel, Store, Reference };
  enum RefType { None, InFlowRef, OutFlowRef, BiFlowRef, InhibitorRef, ResetRef, StoreRef };
  enum CaseSensitive { TokenCaseSensitive, TokenCaseInsensitive }; // Has colored tokens?

  Place();
  virtual ~Place();
  
  void draw(QPainter *p, DrawProps *drawProps); // Pre: p.isActive() && drawProps
  virtual void updateLabels(LabelPlacer *labelPlacer, DrawProps *drawProps); // Pre: labelPlacer && drawProps
  
  virtual const QPointF getConnectionPoint(QPointF source) const;
  virtual const QRect getBoundingRect() const;
  
  inline Type getType() const;
  inline void setType(Type value);
  inline CaseSensitive getCaseSensitive() const;
  inline void setCaseSensitive(CaseSensitive value);
  inline void setReference(Place *value);
  inline Place *getReference() const;
  inline void setRefType(RefType value);
  inline RefType getRefType() const;
  inline void setInitialMarking(int value);
  inline int getInitialMarking() const;
  
  virtual const QString getToolTip() const;
  
#ifdef SHOW_FAKE_ARCS
  QVector<QPoint> *pathGraphics; // TODO: temporarily public for easy access
#endif
protected:
  Place *reference;
  Type type;
  CaseSensitive caseSensitive;
  RefType refType;
  int initialMarking;

};

inline Place::Type Place::getType() const { return type; }
inline void Place::setType(Place::Type value) { type = value; }
inline Place::CaseSensitive Place::getCaseSensitive() const { return caseSensitive; }
inline void Place::setCaseSensitive(Place::CaseSensitive value) { caseSensitive = value; }
inline void Place::setReference(Place *value) { reference = value; }
inline Place *Place::getReference() const { return reference; }
inline void Place::setRefType(Place::RefType value) { refType = value; }
inline Place::RefType Place::getRefType() const { return refType; }
inline void Place::setInitialMarking(int value) { initialMarking = value; }
inline int Place::getInitialMarking() const { return initialMarking; }

#endif //PLACE_H

