/*
 * FILE:    pnmlhandler.h
 * PACKAGE: PNML view
 * LICENCE: See LICENCE file
 * AUTHOR:  Freek van Walderveen
 *
 */

#ifndef PNMLHANDLER_H
#define PNMLHANDLER_H

#include "net.h"
#include "page.h"

#include <QXmlDefaultHandler>
#include <QStack>

class Transition;
class Place;
class Arc;
class Comment;

class PnmlHandler : public QXmlDefaultHandler {
public:
  PnmlHandler();
  virtual ~PnmlHandler();

  bool startElement(const QString &namespaceURI, const QString &localName,
                    const QString &qName, const QXmlAttributes &attributes);
  bool endElement(const QString &namespaceURI, const QString &localName,
                  const QString &qName);
  bool characters(const QString &str);
  bool fatalError(const QXmlParseException &exception);
  QString errorString() const;
  QString fatalErrorString() const;
  
  inline Net *getNet() const;
  inline QString getNetName() const;

private:
  QString currentText;
  QString errorStr, fatalErrorStr;
  bool metPnmlTag;
  bool readingText; // if between <text> and </text>
  
  Transition *curTrans;
  Place *curPlace;
  Arc *curArc;
  Comment *curComment;
  QString curRoleId;
  QStack<Page *> pageStack; // { inv.: all entries are valid, non-null pointers }
  QStack<QString> tagStack;
  
  Net *net;
  
  enum { transition, place, arc, page, comment, role, none } curObject;

};

inline Net *PnmlHandler::getNet() const {
  return net;
}

inline QString PnmlHandler::getNetName() const {
  if (!pageStack.isEmpty()) {
    return pageStack.first()->getName(); // item on bottom of the stack
  } else {
    return QString();
  }
}

#endif
