/*
 * FILE:    transition.h
 * PACKAGE: PNML view
 * LICENCE: See LICENCE file
 * AUTHOR:  Freek van Walderveen
 *
 */

#ifndef TRANSITION_H
#define TRANSITION_H

#include "connectable.h"

#include <QStringList>

class QPainter;

class Transition : public Connectable {
public:
  enum Type { And, Xor, Page, InlinePage };

  Transition();
  virtual void draw(QPainter *p, DrawProps *drawProps); // Pre: p.isActive() && drawProps
  virtual void updateLabels(LabelPlacer *labelPlacer, DrawProps *drawProps); // Pre: labelPlacer && drawProps
  
  virtual const QPointF getConnectionPoint(QPointF source) const;
  virtual const QRect getBoundingRect() const;
  
  void setEmitter(bool value = true);
  void setCollector(bool value = true);
  const QStringList getRoles() const;
  void addRole(QString value);
  
  inline Type getType() const;
  inline void setType(Type value);
  
  inline const QString getPreQuery() const;
  inline void setPreQuery(QString query);
  inline const QString getPostQuery() const;
  inline void setPostQuery(QString query);
  
  inline void setTimeMean(int value);
  inline void setTimeDeviation(int value);
  inline void setFixedCost(int value);
  inline void setVariableCost(int value);
  
  virtual const QString getToolTip() const;
  virtual bool containsPos(QPoint pos) const;
  
protected:
  Type type;
  QStringList roles;
  QString preQuery, postQuery;
  bool isEmitter;
  bool isCollector;
  int timeMean, timeDeviation;
  int fixedCost, variableCost;
};

inline Transition::Type Transition::getType() const {
  return type;
}

inline void Transition::setType(Transition::Type value) {
  type = value;
}

inline const QString Transition::getPreQuery() const {
  return preQuery;
}

inline void Transition::setPreQuery(QString query) {
  preQuery = query;
}

inline const QString Transition::getPostQuery() const {
  return postQuery;
}

inline void Transition::setPostQuery(QString query) {
  postQuery = query;
}
  
inline void Transition::setTimeMean(int value) {
  timeMean = value;
}

inline void Transition::setTimeDeviation(int value) {
  timeDeviation = value;
}

inline void Transition::setFixedCost(int value) {
  fixedCost = value;
}

inline void Transition::setVariableCost(int value) {
  variableCost = value;
}


#endif //TRANSITION_H
